@@ -31,6 +31,11 @@ def main():
     parser.add_argument('-gz', action ='store_const', const = True,
                         default = False, dest ='gz', 
                         help ="if fastq files are in gz format")
+
+    parser.add_argument('-poly(dn)', type = int, default=80, dest = 'n',
+                        help ='poly(n), n*d(A/T/C/G), will report low confidence if contig contains poly(n), default=80', 
+                        )
+    
     parser.add_argument('-output', type = str, default="./",dest = 'outputDir',
                         help ='output directory, default "./"', 
                         )
@@ -66,7 +71,7 @@ def main():
         assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz,args.window)
     elif args.hpvFusion:
         #check result from assemble
-        hpv_fusion(args.humRef,args.virRef,args.outputDir)
+        hpv_fusion(args.humRef,args.virRef,args.outputDir,args.n)
     else:
         alignment(fq1 = args.fq1, fq2 = args.fq2, humRef = args.humRef, virRef = args.virRef, outputDir = args.outputDir, gz = args.gz)
         genomeFusion(args.clusterWindow,args.outputDir,args.virRef)
